From 526b997c9891a796b152cdbab8e329b356b1f596 Mon Sep 17 00:00:00 2001
From: tbrehm <t.brehm@ispconfig.org>
Date: Fri, 22 Feb 2013 08:59:02 -0500
Subject: [PATCH] Merged revisions 3803-3844 from stable branch.

---
 interface/web/sites/web_domain_del.php |   32 ++++++++++++++++++++------------
 1 files changed, 20 insertions(+), 12 deletions(-)

diff --git a/interface/web/sites/web_domain_del.php b/interface/web/sites/web_domain_del.php
index 3f3a49a..cefb0ec 100644
--- a/interface/web/sites/web_domain_del.php
+++ b/interface/web/sites/web_domain_del.php
@@ -55,48 +55,56 @@
 		
 		if($app->tform->checkPerm($this->id,'d') == false) $app->error($app->lng('error_no_delete_permission'));
 		
 		//* Delete all records that belog to this zone.
 		$records = $app->db->queryAllRecords("SELECT domain_id FROM web_domain WHERE parent_domain_id = '".$app->functions->intval($this->id)."' AND type != 'vhost'");
 		foreach($records as $rec) {
 			$app->db->datalogDelete('web_domain','domain_id',$rec['domain_id']);
 		}
 		
 		//* Delete all records that belog to this zone.
 		$records = $app->db->queryAllRecords("SELECT ftp_user_id FROM ftp_user WHERE parent_domain_id = '".$app->functions->intval($this->id)."'");
 		foreach($records as $rec) {
 			$app->db->datalogDelete('ftp_user','ftp_user_id',$rec['ftp_user_id']);
 		}
 		
-		//* Delete all records that belog to this web.
+		//* Delete all records that belong to this web.
 		$records = $app->db->queryAllRecords("SELECT shell_user_id FROM shell_user WHERE parent_domain_id = '".$app->functions->intval($this->id)."'");
 		foreach($records as $rec) {
 			$app->db->datalogDelete('shell_user','shell_user_id',$rec['shell_user_id']);
 		}
         
-        //* Delete all records that belog to this web.
+        //* Delete all records that belong to this web.
         $records = $app->db->queryAllRecords("SELECT id FROM cron WHERE parent_domain_id = '".$app->functions->intval($this->id)."'");
         foreach($records as $rec) {
             $app->db->datalogDelete('cron','id',$rec['id']);
         }
 		
-		//* Delete all records that belog to this web.
-        $records = $app->db->queryAllRecords("SELECT id FROM cron WHERE parent_domain_id = '".$app->functions->intval($this->id)."'");
-        foreach($records as $rec) {
-            $app->db->datalogDelete('cron','id',$rec['id']);
-        }
-		
-		//* Delete all records that belog to this web
+		//* Delete all records that belong to this web
         $records = $app->db->queryAllRecords("SELECT webdav_user_id FROM webdav_user WHERE parent_domain_id = '".$app->functions->intval($this->id)."'");
         foreach($records as $rec) {
             $app->db->datalogDelete('webdav_user','webdav_user_id',$rec['webdav_user_id']);
         }
 		
-		//* Delete all records that belog to this web
+		//* Delete all records that belong to this web
         $records = $app->db->queryAllRecords("SELECT backup_id FROM web_backup WHERE parent_domain_id = '".$app->functions->intval($this->id)."'");
         foreach($records as $rec) {
             $app->db->datalogDelete('web_backup','backup_id',$rec['backup_id']);
         }
 		
+		//* Delete all records that belog to this web.
+		$web_domain = $app->db->queryOneRecord("SELECT domain FROM web_domain WHERE domain_id = ".$app->functions->intval($this->id));
+		if($web_domain['domain'] != ''){
+			$aps_instances = $app->db->queryAllRecords("SELECT instance_id FROM aps_instances_settings WHERE name = 'main_domain' AND value = '".$web_domain['domain']."'");
+			if(is_array($aps_instances) && !empty($aps_instances)){
+				foreach($aps_instances as $aps_instance){
+					if($aps_instance['instance_id'] > 0){
+						$app->db->datalogDelete('aps_instances_settings','instance_id',$aps_instance['instance_id']);
+						$app->db->datalogDelete('aps_instances','id',$aps_instance['instance_id']);
+					}
+				}
+			}
+		}
+		
 		//* Delete all web folders
         $records = $app->db->queryAllRecords("SELECT web_folder_id FROM web_folder WHERE parent_domain_id = '".$app->functions->intval($this->id)."'");
         foreach($records as $rec) {
@@ -55,48 +55,56 @@
 		if($app->tform->checkPerm($this->id,'d') == false) $app->error($app->lng('error_no_delete_permission'));
 		
-		//* Delete all records that belog to this zone.
+		//* Delete all records that belong to this web.
 		$records = $app->db->queryAllRecords("SELECT domain_id FROM web_domain WHERE parent_domain_id = '".$app->functions->intval($this->id)."' AND type != 'vhost'");
 		foreach($records as $rec) {
@@ -55,48 +55,56 @@
 		}
 		
-		//* Delete all records that belog to this zone.
+		//* Delete all records that belong to this web.
 		$records = $app->db->queryAllRecords("SELECT ftp_user_id FROM ftp_user WHERE parent_domain_id = '".$app->functions->intval($this->id)."'");
 		foreach($records as $rec) {

--
Gitblit v1.9.1